@@ -3,7 +3,15 @@
 /* { dg-require-effective-target sse4 } */
 /* { dg-options "-O2 -msse4.1" } */
 
-#include "sse4_1-check.h"
+#ifndef CHECK_H
+#define CHECK_H "sse4_1-check.h"
+#endif
+
+#ifndef TEST
+#define TEST sse4_1_test
+#endif
+
+#include CHECK_H
 
 #include <smmintrin.h>
 
@@ -11,7 +19,8 @@
 #define msk1   1
 
 static void
-sse4_1_test (void)
+__attribute__((noinline))
+TEST (void)
 {
   union
     {
